==> cargo-binstall-1.17.4-1.src.tar.gz: cargo-binstall-1.17.4/crates/binstalk-downloader/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.13.34](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.33...binstalk-downloader-v0.13.34) - 2026-01-27

### Other

- Fix changelog format ([#2454](https://github.com/cargo-bins/cargo-binstall/pull/2454))

## [0.13.33](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.32...binstalk-downloader-v0.13.33) - 2026-01-23

### Other

- updated the following local packages: binstalk-types

## [0.13.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.31...binstalk-downloader-v0.13.32) - 2026-01-18

### Other

- *(deps)* bump the deps group with 8 updates ([#2424](https://github.com/cargo-bins/cargo-binstall/pull/2424))
- Upgrade reqwest to version 0.13.1 ([#2416](https://github.com/cargo-bins/cargo-binstall/pull/2416))

## [0.13.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.30...binstalk-downloader-v0.13.31) - 2025-12-27

### Other

- *(deps)* bump netdev from 0.39.0 to 0.40.0 in the deps group ([#2410](https://github.com/cargo-bins/cargo-binstall/pull/2410))

## [0.13.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.29...binstalk-downloader-v0.13.30) - 2025-12-20

### Other

- Replace doc_auto_cfg with doc_cfg ([#2402](https://github.com/cargo-bins/cargo-binstall/pull/2402))

## [0.13.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.28...binstalk-downloader-v0.13.29) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.13.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.27...binstalk-downloader-v0.13.28) - 2025-11-23

### Other

- Use netdev instead of default-net/ipconfig on Windows ([#2378](https://github.com/cargo-bins/cargo-binstall/pull/2378))

## [0.13.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.26...binstalk-downloader-v0.13.27) - 2025-11-15

### Other

- *(deps)* bump bytes from 1.10.1 to 1.11.0 in the deps group ([#2371](https://github.com/cargo-bins/cargo-binstall/pull/2371))

## [0.13.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.25...binstalk-downloader-v0.13.26) - 2025-11-09

### Other

- Update rc-zip-sync version to 4.3.5 ([#2362](https://github.com/cargo-bins/cargo-binstall/pull/2362))

## [0.13.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.24...binstalk-downloader-v0.13.25) - 2025-10-25

### Fixed

- fix CVE-2025-62518 ([#2340](https://github.com/cargo-bins/cargo-binstall/pull/2340))

### Other

- *(deps)* bump flate2 from 1.1.4 to 1.1.5 in the deps group ([#2342](https://github.com/cargo-bins/cargo-binstall/pull/2342))

## [0.13.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.23...binstalk-downloader-v0.13.24) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))
- *(deps)* bump rc-zip-sync from 4.3.1 to 4.3.2 in the deps group ([#2334](https://github.com/cargo-bins/cargo-binstall/pull/2334))

## [0.13.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.22...binstalk-downloader-v0.13.23) - 2025-09-14

### Added

- respect socks5 in `https_proxy` ([#2306](https://github.com/cargo-bins/cargo-binstall/pull/2306))

## [0.13.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.21...binstalk-downloader-v0.13.22) - 2025-08-30

### Other

- Upgrade compression libraries ([#2289](https://github.com/cargo-bins/cargo-binstall/pull/2289))

## [0.13.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.20...binstalk-downloader-v0.13.21) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))

## [0.13.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.19...binstalk-downloader-v0.13.20) - 2025-06-06

### Other

- updated the following local packages: binstalk-types

## [0.13.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.18...binstalk-downloader-v0.13.19) - 2025-05-30

### Other

- Upgrade reqwest to 0.12.17 ([#2168](https://github.com/cargo-bins/cargo-binstall/pull/2168))

## [0.13.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.17...binstalk-downloader-v0.13.18) - 2025-05-16

### Other

- Upgrade transitive dependencies ([#2154](https://github.com/cargo-bins/cargo-binstall/pull/2154))

## [0.13.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.16...binstalk-downloader-v0.13.17) - 2025-04-05

### Other

- Fix clippy lints ([#2111](https://github.com/cargo-bins/cargo-binstall/pull/2111))

## [0.13.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.15...binstalk-downloader-v0.13.16) - 2025-03-19

### Other

- Fix clippy warnings for detect-targets and binstalk-downloader ([#2098](https://github.com/cargo-bins/cargo-binstall/pull/2098))
- Bump hickory-resolver to 0.25.1 ([#2096](https://github.com/cargo-bins/cargo-binstall/pull/2096))

## [0.13.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.14...binstalk-downloader-v0.13.15) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.13.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.13...binstalk-downloader-v0.13.14) - 2025-03-07

### Other

- Use bzip2/libbz2-rs-sys ([#2071](https://github.com/cargo-bins/cargo-binstall/pull/2071))
- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.13.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.12...binstalk-downloader-v0.13.13) - 2025-02-28

### Other

- Use flate2/zlib-rs for dev/release build ([#2068](https://github.com/cargo-bins/cargo-binstall/pull/2068))

## [0.13.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.11...binstalk-downloader-v0.13.12) - 2025-02-11

### Other

- Upgrade hickory-resolver to 0.25.0-alpha.5 ([#2038](https://github.com/cargo-bins/cargo-binstall/pull/2038))

## [0.13.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.10...binstalk-downloader-v0.13.11) - 2025-02-04

### Added

- *(downloader)* allow remote::Client to be customised (#2035)

## [0.13.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.9...binstalk-downloader-v0.13.10) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.13.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.8...binstalk-downloader-v0.13.9) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.13.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.7...binstalk-downloader-v0.13.8) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.13.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.6...binstalk-downloader-v0.13.7) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.13.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.5...binstalk-downloader-v0.13.6) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.13.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.4...binstalk-downloader-v0.13.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.13.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.3...binstalk-downloader-v0.13.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.13.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.2...binstalk-downloader-v0.13.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.13.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.1...binstalk-downloader-v0.13.2) - 2024-11-02

### Other

- Use rc-zip-sync for zip extraction ([#1942](https://github.com/cargo-bins/cargo-binstall/pull/1942))

## [0.13.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.0...binstalk-downloader-v0.13.1) - 2024-08-12

### Other
- Enable happy eyeballs when using hickory-dns ([#1877](https://github.com/cargo-bins/cargo-binstall/pull/1877))

## [0.13.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.12.0...binstalk-downloader-v0.13.0) - 2024-08-10

### Other
- Bump hickory-resolver to 0.25.0-alpha.2 ([#1869](https://github.com/cargo-bins/cargo-binstall/pull/1869))

==> cargo-binstall-1.17.5-1.src.tar.gz: cargo-binstall-1.17.5/crates/binstalk-downloader/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.13.35](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.34...binstalk-downloader-v0.13.35) - 2026-02-13

### Other

- *(deps)* bump bytes from 1.11.0 to 1.11.1 ([#2478](https://github.com/cargo-bins/cargo-binstall/pull/2478))
- Enable features system-proxy and charset of reqwest by default ([#2474](https://github.com/cargo-bins/cargo-binstall/pull/2474))

## [0.13.34](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.33...binstalk-downloader-v0.13.34) - 2026-01-27

### Other

- Fix changelog format ([#2454](https://github.com/cargo-bins/cargo-binstall/pull/2454))

## [0.13.33](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.32...binstalk-downloader-v0.13.33) - 2026-01-23

### Other

- updated the following local packages: binstalk-types

## [0.13.32](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.31...binstalk-downloader-v0.13.32) - 2026-01-18

### Other

- *(deps)* bump the deps group with 8 updates ([#2424](https://github.com/cargo-bins/cargo-binstall/pull/2424))
- Upgrade reqwest to version 0.13.1 ([#2416](https://github.com/cargo-bins/cargo-binstall/pull/2416))

## [0.13.31](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.30...binstalk-downloader-v0.13.31) - 2025-12-27

### Other

- *(deps)* bump netdev from 0.39.0 to 0.40.0 in the deps group ([#2410](https://github.com/cargo-bins/cargo-binstall/pull/2410))

## [0.13.30](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.29...binstalk-downloader-v0.13.30) - 2025-12-20

### Other

- Replace doc_auto_cfg with doc_cfg ([#2402](https://github.com/cargo-bins/cargo-binstall/pull/2402))

## [0.13.29](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.28...binstalk-downloader-v0.13.29) - 2025-12-05

### Other

- *(deps)* bump the deps group with 2 updates ([#2385](https://github.com/cargo-bins/cargo-binstall/pull/2385))

## [0.13.28](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.27...binstalk-downloader-v0.13.28) - 2025-11-23

### Other

- Use netdev instead of default-net/ipconfig on Windows ([#2378](https://github.com/cargo-bins/cargo-binstall/pull/2378))

## [0.13.27](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.26...binstalk-downloader-v0.13.27) - 2025-11-15

### Other

- *(deps)* bump bytes from 1.10.1 to 1.11.0 in the deps group ([#2371](https://github.com/cargo-bins/cargo-binstall/pull/2371))

## [0.13.26](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.25...binstalk-downloader-v0.13.26) - 2025-11-09

### Other

- Update rc-zip-sync version to 4.3.5 ([#2362](https://github.com/cargo-bins/cargo-binstall/pull/2362))

## [0.13.25](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.24...binstalk-downloader-v0.13.25) - 2025-10-25

### Fixed

- fix CVE-2025-62518 ([#2340](https://github.com/cargo-bins/cargo-binstall/pull/2340))

### Other

- *(deps)* bump flate2 from 1.1.4 to 1.1.5 in the deps group ([#2342](https://github.com/cargo-bins/cargo-binstall/pull/2342))

## [0.13.24](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.23...binstalk-downloader-v0.13.24) - 2025-10-24

### Other

- *(lints)* introduce typos-cli config in `Cargo.toml` and handle typos ([#2337](https://github.com/cargo-bins/cargo-binstall/pull/2337))
- *(deps)* bump rc-zip-sync from 4.3.1 to 4.3.2 in the deps group ([#2334](https://github.com/cargo-bins/cargo-binstall/pull/2334))

## [0.13.23](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.22...binstalk-downloader-v0.13.23) - 2025-09-14

### Added

- respect socks5 in `https_proxy` ([#2306](https://github.com/cargo-bins/cargo-binstall/pull/2306))

## [0.13.22](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.21...binstalk-downloader-v0.13.22) - 2025-08-30

### Other

- Upgrade compression libraries ([#2289](https://github.com/cargo-bins/cargo-binstall/pull/2289))

## [0.13.21](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.20...binstalk-downloader-v0.13.21) - 2025-07-25

### Other

- *(deps)* bump tokio from 1.46.0 to 1.46.1 in the deps group ([#2222](https://github.com/cargo-bins/cargo-binstall/pull/2222))

## [0.13.20](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.19...binstalk-downloader-v0.13.20) - 2025-06-06

### Other

- updated the following local packages: binstalk-types

## [0.13.19](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.18...binstalk-downloader-v0.13.19) - 2025-05-30

### Other

- Upgrade reqwest to 0.12.17 ([#2168](https://github.com/cargo-bins/cargo-binstall/pull/2168))

## [0.13.18](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.17...binstalk-downloader-v0.13.18) - 2025-05-16

### Other

- Upgrade transitive dependencies ([#2154](https://github.com/cargo-bins/cargo-binstall/pull/2154))

## [0.13.17](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.16...binstalk-downloader-v0.13.17) - 2025-04-05

### Other

- Fix clippy lints ([#2111](https://github.com/cargo-bins/cargo-binstall/pull/2111))

## [0.13.16](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.15...binstalk-downloader-v0.13.16) - 2025-03-19

### Other

- Fix clippy warnings for detect-targets and binstalk-downloader ([#2098](https://github.com/cargo-bins/cargo-binstall/pull/2098))
- Bump hickory-resolver to 0.25.1 ([#2096](https://github.com/cargo-bins/cargo-binstall/pull/2096))

## [0.13.15](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.14...binstalk-downloader-v0.13.15) - 2025-03-15

### Other

- *(deps)* bump the deps group with 2 updates ([#2084](https://github.com/cargo-bins/cargo-binstall/pull/2084))
- *(deps)* bump tokio from 1.43.0 to 1.44.0 in the deps group ([#2079](https://github.com/cargo-bins/cargo-binstall/pull/2079))

## [0.13.14](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.13...binstalk-downloader-v0.13.14) - 2025-03-07

### Other

- Use bzip2/libbz2-rs-sys ([#2071](https://github.com/cargo-bins/cargo-binstall/pull/2071))
- *(deps)* bump the deps group with 3 updates ([#2072](https://github.com/cargo-bins/cargo-binstall/pull/2072))

## [0.13.13](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.12...binstalk-downloader-v0.13.13) - 2025-02-28

### Other

- Use flate2/zlib-rs for dev/release build ([#2068](https://github.com/cargo-bins/cargo-binstall/pull/2068))

## [0.13.12](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.11...binstalk-downloader-v0.13.12) - 2025-02-11

### Other

- Upgrade hickory-resolver to 0.25.0-alpha.5 ([#2038](https://github.com/cargo-bins/cargo-binstall/pull/2038))

## [0.13.11](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.10...binstalk-downloader-v0.13.11) - 2025-02-04

### Added

- *(downloader)* allow remote::Client to be customised (#2035)

## [0.13.10](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.9...binstalk-downloader-v0.13.10) - 2025-01-19

### Other

- update Cargo.lock dependencies

## [0.13.9](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.8...binstalk-downloader-v0.13.9) - 2025-01-13

### Other

- update Cargo.lock dependencies

## [0.13.8](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.7...binstalk-downloader-v0.13.8) - 2025-01-11

### Other

- *(deps)* bump the deps group with 3 updates (#2015)

## [0.13.7](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.6...binstalk-downloader-v0.13.7) - 2025-01-04

### Other

- *(deps)* bump the deps group with 2 updates (#2010)

## [0.13.6](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.5...binstalk-downloader-v0.13.6) - 2024-12-14

### Other

- *(deps)* bump the deps group with 2 updates (#1997)

## [0.13.5](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.4...binstalk-downloader-v0.13.5) - 2024-11-23

### Other

- *(deps)* bump the deps group with 2 updates ([#1981](https://github.com/cargo-bins/cargo-binstall/pull/1981))

## [0.13.4](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.3...binstalk-downloader-v0.13.4) - 2024-11-09

### Other

- *(deps)* bump the deps group with 3 updates ([#1966](https://github.com/cargo-bins/cargo-binstall/pull/1966))

## [0.13.3](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.2...binstalk-downloader-v0.13.3) - 2024-11-05

### Other

- *(deps)* bump the deps group with 3 updates ([#1954](https://github.com/cargo-bins/cargo-binstall/pull/1954))

## [0.13.2](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.1...binstalk-downloader-v0.13.2) - 2024-11-02

### Other

- Use rc-zip-sync for zip extraction ([#1942](https://github.com/cargo-bins/cargo-binstall/pull/1942))

## [0.13.1](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.13.0...binstalk-downloader-v0.13.1) - 2024-08-12

### Other
- Enable happy eyeballs when using hickory-dns ([#1877](https://github.com/cargo-bins/cargo-binstall/pull/1877))

## [0.13.0](https://github.com/cargo-bins/cargo-binstall/compare/binstalk-downloader-v0.12.0...binstalk-downloader-v0.13.0) - 2024-08-10

### Other
- Bump hickory-resolver to 0.25.0-alpha.2 ([#1869](https://github.com/cargo-bins/cargo-binstall/pull/1869))
